@@ -14,6 +14,8 @@ from bakery.partitioning import (
     list_drives,
 )
 
+from bakery.install import install as binstall
+
 from time import sleep
 from pytz import timezone
 from datetime import datetime
@@ -691,6 +693,9 @@ def user_menu() -> None:
 def summary_confirm(manifest: dict) -> bool:
     sidebar = SIDEBAR.copy()
     sidebar["Summary"] = True
+    de = manifest["session_configuration"]["de"]
+    if de is None:
+        de = "None detected."
     data = [
         "Ready to install. Please and confirm:",
         "",
@@ -701,7 +706,7 @@ def summary_confirm(manifest: dict) -> bool:
         "",
         "Session Configuration:",
         " - Display Manager     : " + manifest["session_configuration"]["dm"],
-        " - Desktop Environment : " + manifest["session_configuration"]["de"],
+        " - Desktop Environment : " + de,
         " - Wayland             : "
         + str(manifest["session_configuration"]["is_wayland"]),
         "",
@@ -712,10 +717,12 @@ def summary_confirm(manifest: dict) -> bool:
         " - Source : " + manifest["layout"]["layout"],
         " - Device : " + manifest["layout"]["variant"],
         "",
-        "Locale: ",
-        " - Region : " + manifest["locale"]["region"],
-        " - Zone   : " + manifest["locale"]["zone"],
-        " - NTP    : " + str(manifest["locale"]["ntp"]),
+        "Locale: " + manifest["locale"],
+        "",
+        "Timezone: ",
+        " - Region : " + manifest["timezone"]["region"],
+        " - Zone   : " + manifest["timezone"]["zone"],
+        " - NTP    : " + str(manifest["timezone"]["ntp"]),
         "",
         "Hostname: " + manifest["hostname"],
         "",
@@ -747,7 +754,11 @@ def summary_confirm(manifest: dict) -> bool:
 
 def install(manifest: dict) -> bool:
     c.suspend()
-    install(manifest)
+    print("=====================")
+    print("STARTING INSTALLATION")
+    print("     PLEASE WAIT     ")
+    print("=====================")
+    binstall(manifest)
     c.resume()
     return True
 
@@ -776,7 +787,7 @@ def main_menu() -> None:
                     sidebar=sidebar,
                 ):
                     stage = 1  # Locale
-                elif DRYRUN:
+                else:
                     return
             elif stage == 1:
                 locale = locale_menu()
@@ -792,7 +803,7 @@ def main_menu() -> None:
                 timezone = timezone_menu()
                 stage = 2 if timezone is None else 4
             elif stage == 4:
-                if INSTALL_TYPE == "from_iso" or True:
+                if INSTALL_TYPE == "from_iso":
                     parts = partitioning_menu()
                     stage = 3 if parts is None else 5
                 else:
@@ -810,10 +821,12 @@ def main_menu() -> None:
                     "session_configuration": detect_session_configuration(),
                     "root_password": False,
                     "layout": keyboard,
-                    "locale": timezone,
+                    "locale": locale,
+                    "timezone": timezone,
                     "hostname": user[0],
                     "user": user[1],
                     "installer": {
+                        "shown_pages": list(sidebar.keys()),
                         "installer_version": config.installer_version,
                         "ui": "tui",
                     },
@@ -838,6 +851,8 @@ def main_menu() -> None:
                         "Press Enter to reboot into your new installation.",
                     ]
                 )
+
+                c.suspend()
                 if not DRYRUN:
                     reboot()
         except KeyboardInterrupt:
